"use client"

import type React from "react"

import { useState } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Checkbox } from "@/components/ui/checkbox"
import {
  FileText,
  Upload,
  ArrowLeft,
  CheckCircle,
  AlertCircle,
  GraduationCap,
  User,
  BookOpen,
  Award,
  Send,
} from "lucide-react"
import Link from "next/link"

export default function WriterApplicationPage() {
  const router = useRouter()
  const [isLoading, setIsLoading] = useState(false)
  const [formData, setFormData] = useState({
    // Personal Information
    firstName: "",
    lastName: "",
    email: "",
    phone: "",
    country: "",
    timezone: "",

    // Professional Information
    education: "",
    institution: "",
    graduationYear: "",
    experience: "",
    currentOccupation: "",

    // Writing Expertise
    specializations: [] as string[],
    writingExperience: "",
    portfolioUrl: "",
    sampleWork: null as File | null,

    // Additional Information
    bio: "",
    availability: "",
    preferredSubjects: [] as string[],

    // Agreements
    agreeToTerms: false,
    agreeToQuality: false,
    agreeToDeadlines: false,
  })

  const subjects = [
    "English Literature",
    "Creative Writing",
    "Business Administration",
    "Marketing",
    "Psychology",
    "Sociology",
    "History",
    "Political Science",
    "Economics",
    "Computer Science",
    "Information Technology",
    "Engineering",
    "Mathematics",
    "Biology",
    "Chemistry",
    "Physics",
    "Environmental Science",
    "Medicine",
    "Nursing",
    "Education",
    "Philosophy",
    "Law",
    "Accounting",
    "Finance",
  ]

  const handleSubjectToggle = (subject: string) => {
    setFormData((prev) => ({
      ...prev,
      preferredSubjects: prev.preferredSubjects.includes(subject)
        ? prev.preferredSubjects.filter((s) => s !== subject)
        : [...prev.preferredSubjects, subject],
    }))
  }

  const handleSpecializationToggle = (specialization: string) => {
    setFormData((prev) => ({
      ...prev,
      specializations: prev.specializations.includes(specialization)
        ? prev.specializations.filter((s) => s !== specialization)
        : [...prev.specializations, specialization],
    }))
  }

  const handleFileUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    if (e.target.files && e.target.files[0]) {
      setFormData({ ...formData, sampleWork: e.target.files[0] })
    }
  }

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setIsLoading(true)

    try {
      // Simulate application submission
      await new Promise((resolve) => setTimeout(resolve, 2000))

      alert(`Application submitted successfully!

Thank you for applying to become a writer with ProEssayWorks.

Your application will be reviewed by our team within 3-5 business days. We'll contact you at ${formData.email} with the results.

Application Details:
- Name: ${formData.firstName} ${formData.lastName}
- Education: ${formData.education}
- Specializations: ${formData.specializations.join(", ")}
- Preferred Subjects: ${formData.preferredSubjects.join(", ")}

Next Steps:
1. We'll review your qualifications and sample work
2. If approved, you'll receive login credentials
3. Complete your profile setup
4. Start browsing and applying for orders

Good luck!`)

      // Redirect to login page
      router.push("/auth/login?message=application-submitted")
    } catch (error) {
      alert("Error submitting application. Please try again.")
    } finally {
      setIsLoading(false)
    }
  }

  const isFormValid = () => {
    return (
      formData.firstName &&
      formData.lastName &&
      formData.email &&
      formData.phone &&
      formData.education &&
      formData.experience &&
      formData.bio &&
      formData.specializations.length > 0 &&
      formData.preferredSubjects.length > 0 &&
      formData.agreeToTerms &&
      formData.agreeToQuality &&
      formData.agreeToDeadlines
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Header */}
      <header className="bg-white shadow-sm border-b">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-4">
            <div className="flex items-center">
              <GraduationCap className="h-8 w-8 text-blue-600" />
              <span className="ml-2 text-xl font-bold text-gray-900">ProEssayWorks</span>
            </div>
            <Link href="/">
              <Button variant="outline">
                <ArrowLeft className="h-4 w-4 mr-2" />
                Back to Home
              </Button>
            </Link>
          </div>
        </div>
      </header>

      <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="mb-8">
          <h1 className="text-3xl font-bold text-gray-900 mb-2">Join Our Writer Community</h1>
          <p className="text-gray-600">Apply to become a professional academic writer with ProEssayWorks</p>
        </div>

        {/* Requirements Card */}
        <Card className="mb-8 border-blue-200 bg-blue-50">
          <CardHeader>
            <CardTitle className="flex items-center text-blue-800">
              <CheckCircle className="h-5 w-5 mr-2" />
              Writer Requirements
            </CardTitle>
          </CardHeader>
          <CardContent>
            <div className="grid grid-cols-1 md:grid-cols-2 gap-4 text-sm">
              <div className="space-y-2">
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Bachelor's degree or higher</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Excellent English writing skills</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Academic writing experience</span>
                </div>
              </div>
              <div className="space-y-2">
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Reliable internet connection</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Commitment to deadlines</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-4 w-4 text-green-600 mr-2" />
                  <span>Professional communication</span>
                </div>
              </div>
            </div>
          </CardContent>
        </Card>

        <form onSubmit={handleSubmit} className="space-y-8">
          {/* Personal Information */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <User className="h-5 w-5 mr-2" />
                Personal Information
              </CardTitle>
              <CardDescription>Basic contact and personal details</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                  <Label htmlFor="firstName">First Name *</Label>
                  <Input
                    id="firstName"
                    value={formData.firstName}
                    onChange={(e) => setFormData({ ...formData, firstName: e.target.value })}
                    required
                  />
                </div>
                <div>
                  <Label htmlFor="lastName">Last Name *</Label>
                  <Input
                    id="lastName"
                    value={formData.lastName}
                    onChange={(e) => setFormData({ ...formData, lastName: e.target.value })}
                    required
                  />
                </div>
              </div>

              <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                  <Label htmlFor="email">Email Address *</Label>
                  <Input
                    id="email"
                    type="email"
                    value={formData.email}
                    onChange={(e) => setFormData({ ...formData, email: e.target.value })}
                    required
                  />
                </div>
                <div>
                  <Label htmlFor="phone">Phone Number *</Label>
                  <Input
                    id="phone"
                    type="tel"
                    value={formData.phone}
                    onChange={(e) => setFormData({ ...formData, phone: e.target.value })}
                    required
                  />
                </div>
              </div>

              <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                  <Label htmlFor="country">Country *</Label>
                  <Select
                    value={formData.country}
                    onValueChange={(value) => setFormData({ ...formData, country: value })}
                  >
                    <SelectTrigger>
                      <SelectValue placeholder="Select your country" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="us">United States</SelectItem>
                      <SelectItem value="uk">United Kingdom</SelectItem>
                      <SelectItem value="ca">Canada</SelectItem>
                      <SelectItem value="au">Australia</SelectItem>
                      <SelectItem value="other">Other</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
                <div>
                  <Label htmlFor="timezone">Timezone</Label>
                  <Select
                    value={formData.timezone}
                    onValueChange={(value) => setFormData({ ...formData, timezone: value })}
                  >
                    <SelectTrigger>
                      <SelectValue placeholder="Select your timezone" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="est">Eastern Time (EST)</SelectItem>
                      <SelectItem value="cst">Central Time (CST)</SelectItem>
                      <SelectItem value="mst">Mountain Time (MST)</SelectItem>
                      <SelectItem value="pst">Pacific Time (PST)</SelectItem>
                      <SelectItem value="gmt">Greenwich Mean Time (GMT)</SelectItem>
                    </SelectContent>
                  </Select>
                </div>
              </div>
            </CardContent>
          </Card>

          {/* Educational Background */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <GraduationCap className="h-5 w-5 mr-2" />
                Educational Background
              </CardTitle>
              <CardDescription>Your academic qualifications and achievements</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <Label htmlFor="education">Highest Degree *</Label>
                <Select
                  value={formData.education}
                  onValueChange={(value) => setFormData({ ...formData, education: value })}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="Select your highest degree" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="bachelor">Bachelor's Degree</SelectItem>
                    <SelectItem value="master">Master's Degree</SelectItem>
                    <SelectItem value="phd">PhD/Doctorate</SelectItem>
                    <SelectItem value="professional">Professional Degree</SelectItem>
                  </SelectContent>
                </Select>
              </div>

              <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                  <Label htmlFor="institution">Institution</Label>
                  <Input
                    id="institution"
                    value={formData.institution}
                    onChange={(e) => setFormData({ ...formData, institution: e.target.value })}
                    placeholder="University or college name"
                  />
                </div>
                <div>
                  <Label htmlFor="graduationYear">Graduation Year</Label>
                  <Input
                    id="graduationYear"
                    type="number"
                    min="1990"
                    max="2024"
                    value={formData.graduationYear}
                    onChange={(e) => setFormData({ ...formData, graduationYear: e.target.value })}
                  />
                </div>
              </div>

              <div>
                <Label htmlFor="currentOccupation">Current Occupation</Label>
                <Input
                  id="currentOccupation"
                  value={formData.currentOccupation}
                  onChange={(e) => setFormData({ ...formData, currentOccupation: e.target.value })}
                  placeholder="Your current job or profession"
                />
              </div>
            </CardContent>
          </Card>

          {/* Writing Experience */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <BookOpen className="h-5 w-5 mr-2" />
                Writing Experience
              </CardTitle>
              <CardDescription>Your writing background and expertise</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <Label htmlFor="experience">Years of Writing Experience *</Label>
                <Select
                  value={formData.experience}
                  onValueChange={(value) => setFormData({ ...formData, experience: value })}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="Select your experience level" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="1-2">1-2 years</SelectItem>
                    <SelectItem value="3-5">3-5 years</SelectItem>
                    <SelectItem value="5-10">5-10 years</SelectItem>
                    <SelectItem value="10+">10+ years</SelectItem>
                  </SelectContent>
                </Select>
              </div>

              <div>
                <Label>Writing Specializations *</Label>
                <p className="text-sm text-gray-600 mb-2">Select your areas of expertise (choose at least one)</p>
                <div className="grid grid-cols-2 md:grid-cols-3 gap-2">
                  {[
                    "Academic Writing",
                    "Research Papers",
                    "Essays",
                    "Case Studies",
                    "Literature Reviews",
                    "Dissertations",
                    "Technical Writing",
                    "Business Writing",
                    "Creative Writing",
                  ].map((spec) => (
                    <div key={spec} className="flex items-center space-x-2">
                      <Checkbox
                        id={spec}
                        checked={formData.specializations.includes(spec)}
                        onCheckedChange={() => handleSpecializationToggle(spec)}
                      />
                      <Label htmlFor={spec} className="text-sm">
                        {spec}
                      </Label>
                    </div>
                  ))}
                </div>
              </div>

              <div>
                <Label htmlFor="portfolioUrl">Portfolio URL (Optional)</Label>
                <Input
                  id="portfolioUrl"
                  type="url"
                  value={formData.portfolioUrl}
                  onChange={(e) => setFormData({ ...formData, portfolioUrl: e.target.value })}
                  placeholder="https://your-portfolio.com"
                />
              </div>

              <div>
                <Label htmlFor="sampleWork">Sample Work (Optional)</Label>
                <div className="border-2 border-dashed border-gray-300 rounded-lg p-6 text-center">
                  <Upload className="h-8 w-8 text-gray-400 mx-auto mb-2" />
                  <p className="text-sm text-gray-600 mb-2">
                    Upload a sample of your academic writing (PDF, DOC, DOCX)
                  </p>
                  <Input
                    id="sampleWork"
                    type="file"
                    accept=".pdf,.doc,.docx"
                    onChange={handleFileUpload}
                    className="hidden"
                  />
                  <Button
                    type="button"
                    variant="outline"
                    onClick={() => document.getElementById("sampleWork")?.click()}
                  >
                    Choose File
                  </Button>
                  {formData.sampleWork && (
                    <div className="mt-2 text-sm text-gray-600">Selected: {formData.sampleWork.name}</div>
                  )}
                </div>
              </div>
            </CardContent>
          </Card>

          {/* Subject Preferences */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <Award className="h-5 w-5 mr-2" />
                Subject Preferences
              </CardTitle>
              <CardDescription>Select the subjects you're most comfortable writing about</CardDescription>
            </CardHeader>
            <CardContent>
              <div>
                <Label>Preferred Subjects *</Label>
                <p className="text-sm text-gray-600 mb-3">Choose at least 3 subjects you specialize in</p>
                <div className="grid grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-2">
                  {subjects.map((subject) => (
                    <div key={subject} className="flex items-center space-x-2">
                      <Checkbox
                        id={subject}
                        checked={formData.preferredSubjects.includes(subject)}
                        onCheckedChange={() => handleSubjectToggle(subject)}
                      />
                      <Label htmlFor={subject} className="text-sm">
                        {subject}
                      </Label>
                    </div>
                  ))}
                </div>
                <p className="text-sm text-gray-500 mt-2">Selected: {formData.preferredSubjects.length} subjects</p>
              </div>
            </CardContent>
          </Card>

          {/* Professional Bio */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <FileText className="h-5 w-5 mr-2" />
                Professional Information
              </CardTitle>
              <CardDescription>Tell us about yourself and your availability</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <Label htmlFor="bio">Professional Bio *</Label>
                <Textarea
                  id="bio"
                  value={formData.bio}
                  onChange={(e) => setFormData({ ...formData, bio: e.target.value })}
                  placeholder="Describe your background, expertise, and what makes you a great academic writer..."
                  rows={5}
                  required
                />
                <p className="text-sm text-gray-500 mt-1">{formData.bio.length}/500 characters</p>
              </div>

              <div>
                <Label htmlFor="availability">Availability</Label>
                <Select
                  value={formData.availability}
                  onValueChange={(value) => setFormData({ ...formData, availability: value })}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="How many hours per week can you dedicate?" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="part-time">Part-time (10-20 hours/week)</SelectItem>
                    <SelectItem value="full-time">Full-time (30-40 hours/week)</SelectItem>
                    <SelectItem value="flexible">Flexible schedule</SelectItem>
                    <SelectItem value="weekends">Weekends only</SelectItem>
                  </SelectContent>
                </Select>
              </div>
            </CardContent>
          </Card>

          {/* Terms and Agreements */}
          <Card>
            <CardHeader>
              <CardTitle className="flex items-center">
                <CheckCircle className="h-5 w-5 mr-2" />
                Terms and Agreements
              </CardTitle>
              <CardDescription>Please review and accept our terms</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div className="space-y-3">
                <div className="flex items-start space-x-3">
                  <Checkbox
                    id="agreeToTerms"
                    checked={formData.agreeToTerms}
                    onCheckedChange={(checked) => setFormData({ ...formData, agreeToTerms: checked as boolean })}
                  />
                  <div>
                    <Label htmlFor="agreeToTerms" className="text-sm font-medium">
                      I agree to the Terms of Service and Privacy Policy *
                    </Label>
                    <p className="text-xs text-gray-600">
                      By checking this box, you agree to our platform terms and conditions.
                    </p>
                  </div>
                </div>

                <div className="flex items-start space-x-3">
                  <Checkbox
                    id="agreeToQuality"
                    checked={formData.agreeToQuality}
                    onCheckedChange={(checked) => setFormData({ ...formData, agreeToQuality: checked as boolean })}
                  />
                  <div>
                    <Label htmlFor="agreeToQuality" className="text-sm font-medium">
                      I commit to delivering high-quality, original work *
                    </Label>
                    <p className="text-xs text-gray-600">
                      All work must be original, well-researched, and meet academic standards.
                    </p>
                  </div>
                </div>

                <div className="flex items-start space-x-3">
                  <Checkbox
                    id="agreeToDeadlines"
                    checked={formData.agreeToDeadlines}
                    onCheckedChange={(checked) => setFormData({ ...formData, agreeToDeadlines: checked as boolean })}
                  />
                  <div>
                    <Label htmlFor="agreeToDeadlines" className="text-sm font-medium">
                      I understand the importance of meeting deadlines *
                    </Label>
                    <p className="text-xs text-gray-600">
                      Timely delivery is crucial for client satisfaction and platform success.
                    </p>
                  </div>
                </div>
              </div>
            </CardContent>
          </Card>

          {/* Submit Button */}
          <div className="flex justify-center">
            <Button
              type="submit"
              className="w-full max-w-md btn-academic-primary"
              disabled={isLoading || !isFormValid()}
            >
              {isLoading ? (
                <>
                  <div className="animate-spin rounded-full h-4 w-4 border-b-2 border-white mr-2"></div>
                  Submitting Application...
                </>
              ) : (
                <>
                  <Send className="h-4 w-4 mr-2" />
                  Submit Writer Application
                </>
              )}
            </Button>
          </div>

          {!isFormValid() && (
            <div className="text-center">
              <p className="text-sm text-red-600">
                Please fill in all required fields and accept the terms to submit your application.
              </p>
            </div>
          )}
        </form>

        {/* What Happens Next */}
        <Card className="mt-8 border-green-200 bg-green-50">
          <CardHeader>
            <CardTitle className="flex items-center text-green-800">
              <AlertCircle className="h-5 w-5 mr-2" />
              What Happens Next?
            </CardTitle>
          </CardHeader>
          <CardContent>
            <div className="space-y-3 text-sm text-green-700">
              <div className="flex items-center">
                <div className="w-6 h-6 bg-green-600 text-white rounded-full flex items-center justify-center text-xs font-bold mr-3">
                  1
                </div>
                <span>Application Review (3-5 business days)</span>
              </div>
              <div className="flex items-center">
                <div className="w-6 h-6 bg-green-600 text-white rounded-full flex items-center justify-center text-xs font-bold mr-3">
                  2
                </div>
                <span>Email notification with results</span>
              </div>
              <div className="flex items-center">
                <div className="w-6 h-6 bg-green-600 text-white rounded-full flex items-center justify-center text-xs font-bold mr-3">
                  3
                </div>
                <span>If approved, receive login credentials</span>
              </div>
              <div className="flex items-center">
                <div className="w-6 h-6 bg-green-600 text-white rounded-full flex items-center justify-center text-xs font-bold mr-3">
                  4
                </div>
                <span>Complete profile setup and start earning</span>
              </div>
            </div>
          </CardContent>
        </Card>
      </div>
    </div>
  )
}
